<!-- PROJECT SHIELDS -->
<!--
*** I'm using markdown "reference style" links for readability.
*** Reference links are enclosed in brackets [ ] instead of parentheses ( ).
*** See the bottom of this document for the declaration of the reference variables
*** for contributors-url, forks-url, etc. This is an optional, concise syntax you may use.
*** https://www.markdownguide.org/basic-syntax/#reference-style-links
-->
[![Contributors][contributors-shield]][contributors-url]
[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![MIT License][license-shield]][license-url]



<!-- PROJECT LOGO -->
<br />
<p align="center">
  <a href="https://github.com/YonLiud/Israeli-Queue">
    <img src="https://i.ibb.co/bgJQ792/logo.png" alt="Logo" width="80" height="80">
  </a>

  <h3 align="center">Israeli Queue</h3>

  <p align="center">
    Israeli Queues are a variation of Priority Queues where instead of associating priority with the element to be enqueued, the pr
 </p>

</p>





<!-- ABOUT THE PROJECT -->
## About The Project

A project planned and built by 3 Israeli 11 grades that met on the Offical Python Discord

## About Israeli Queues

Queues in Israel are usually unorganized, due to which people tend to find their friends, who are already waiting, and instead of adhering to the usual protocol of joining at the back end, they cut through and directly join their friends. Israeli Queues mimic this behavior and hence get this punny name.


<!-- GETTING STARTED -->
## Getting Started

To get the module working simply follow these steps:

### Installation

```sh
pip install IsraeliQueue
```


<!-- USAGE EXAMPLES -->
## Usage Example

<a href="https://ibb.co/2kbWsKQ"><img src="https://i.ibb.co/kSd59cf/carbon-1.png" alt="carbon-1" border="0"></a>

Returns: `[Item(item='Noy', group=0), Item(item='Nitzan', group=0), Item(item='Omry', group=1), Item(item='Omer', group=1), Item(item='Oz', group=1), Item(item='Alma', group=2)]`

<!-- ROADMAP 
## Roadmap

See the [open issues](https://github.com/YonLiud/Israeli-Queue/issues) for a list of proposed features (and known issues).
-->


<!-- CONTRIBUTING -->
## Contributing

Contributions are what make the open source community such an amazing place to be learn, inspire, and create. Any contributions you make are **greatly appreciated**.

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request



<!-- LICENSE -->
## License

Distributed under the MIT License. See `LICENSE` for more information.



<!-- CONTACT -->
## Contact

Project Link: [https://github.com/YonLiud/Israeli-Queue](https://github.com/YonLiud/Israeli-Queue)



<!-- ACKNOWLEDGEMENTS
## Acknowledgements

* []()
* []()
* []()

 -->



<!-- MARKDOWN LINKS & IMAGES -->
<!-- https://www.markdownguide.org/basic-syntax/#reference-style-links -->
[contributors-shield]: https://img.shields.io/github/contributors/YonLiud/Israeli-Queue.svg?style=for-the-badge
[contributors-url]: https://github.com/YonLiud/Israeli-Queue/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/YonLiud/Israeli-Queue.svg?style=for-the-badge
[forks-url]: https://github.com/YonLiud/Israeli-Queue/network/members
[stars-shield]: https://img.shields.io/github/stars/YonLiud/Israeli-Queue.svg?style=for-the-badge
[stars-url]: https://github.com/YonLiud/Israeli-Queue/stargazers
[issues-shield]: https://img.shields.io/github/issues/YonLiud/Israeli-Queue.svg?style=for-the-badge
[issues-url]: https://github.com/YonLiud/Israeli-Queue/issues
[license-shield]: https://img.shields.io/github/license/YonLiud/Israeli-Queue.svg?style=for-the-badge
[license-url]: https://github.com/YonLiud/Israeli-Queue/blob/master/LICENSE.txt
[linkedin-shield]: https://img.shields.io/badge/-LinkedIn-black.svg?style=for-the-badge&logo=linkedin&colorB=555
[linkedin-url]: https://linkedin.com/in/YonLiud